from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from ..l0.Object import Object

if TYPE_CHECKING:
    from rdflib import Graph

    from .Method import Method
    from .Platform import Platform


class MonitoringFacility(Object):
    __type__ = IOT["MonitoringFacility"]

    implementsMethod: List[Method] = None
    isHostedByPlatform: List[Platform] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.implementsMethod:
            for implementsMethod in self.implementsMethod:
                g.add(
                    (self.uriRef, IOT["implementsMethod"], implementsMethod.uriRef))

        if self.isHostedByPlatform:
            for isHostedByPlatform in self.isHostedByPlatform:
                g.add(
                    (self.uriRef, IOT["isHostedByPlatform"], isHostedByPlatform.uriRef))



from .AccessCondition import AccessCondition
from .AdmissionType import AdmissionType
from .Booking import Booking
from .OpeningHoursSpecification import OpeningHoursSpecification
from .TemporaryClosure import TemporaryClosure



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..cpev.PublicEvent import PublicEvent
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .CulturalEntity import CulturalEntity
    from .Site import Site


class CulturalEvent(PublicEvent):
    __type__ = CIS["CulturalEvent"]

    isHostedBySite: List[Site] = None
    involvesCulturalEntity: List[CulturalEntity] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isHostedBySite:
            for isHostedBySite in self.isHostedBySite:
                g.add(
                    (self.uriRef, CIS["isHostedBySite"], isHostedBySite.uriRef))

        if self.involvesCulturalEntity:
            for involvesCulturalEntity in self.involvesCulturalEntity:
                g.add(
                    (self.uriRef, CIS["involvesCulturalEntity"], involvesCulturalEntity.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from ..mu.Value import Value

if TYPE_CHECKING:
    from rdflib import Graph

    from .Observation import Observation
    from .ObservationParameter import ObservationParameter


class ObservationValue(Value):
    __type__ = IOT["ObservationValue"]

    isObservationValueOf: List[Observation] = None
    isValueForObservationParameter: List[ObservationParameter] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isObservationValueOf:
            for isObservationValueOf in self.isObservationValueOf:
                g.add(
                    (self.uriRef, IOT["isObservationValueOf"], isObservationValueOf.uriRef))

        if self.isValueForObservationParameter:
            for isValueForObservationParameter in self.isValueForObservationParameter:
                g.add(
                    (self.uriRef, IOT["isValueForObservationParameter"], isValueForObservationParameter.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.EventOrSituation import EventOrSituation
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .EventType import EventType
    from .PublicService import PublicService


class EventOrSituation(EventOrSituation):
    __type__ = CPSV["EventOrSituation"]

    hasEventType: List[EventType] = None
    isEventForPS: List[PublicService] = None
    name: List[Literal] = None
    description: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasEventType:
            for hasEventType in self.hasEventType:
                g.add((self.uriRef, CPSV["hasEventType"], hasEventType.uriRef))

        if self.isEventForPS:
            for isEventForPS in self.isEventForPS:
                g.add((self.uriRef, CPSV["isEventForPS"], isEventForPS.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))



from .Accuracy import Accuracy
from .Actuator import Actuator
from .FeatureOfInterest import FeatureOfInterest
from .Frequency import Frequency
from .Latency import Latency
from .MeasurementQuality import MeasurementQuality
from .MeasurementQualityValue import MeasurementQualityValue
from .Method import Method
from .MonitoringFacility import MonitoringFacility
from .Observation import Observation
from .ObservationCollection import ObservationCollection
from .ObservationParameter import ObservationParameter
from .ObservationValue import ObservationValue
from .Offset import Offset
from .Platform import Platform
from .Precision import Precision
from .Repetability import Repetability
from .RoadSegment import RoadSegment
from .Sensor import Sensor
from .TrafficFlow import TrafficFlow



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .AccessCondition import AccessCondition

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class Booking(AccessCondition):
    __type__ = ACOND["Booking"]

    name: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isAccessConditionOf:
            for isAccessConditionOf in self.isAccessConditionOf:
                g.add((self.uriRef, ACOND["isAccessConditionOf"],
                       isAccessConditionOf.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Notice import Notice

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class CallForCompetition(Notice):
    __type__ = PUBC["CallForCompetition"]

    expireDate: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.expireDate:
            for expireDate in self.expireDate:
                g.add(
                    (self.uriRef, PUBC["expireDate"], expireDate))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Requirement import Requirement

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class StandardTech(Requirement):
    __type__ = CPSV["StandardTech"]

    referenceDoc: List[Literal] = None
    description: List[Literal] = None
    identifier: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.referenceDoc:
            for referenceDoc in self.referenceDoc:
                g.add((self.uriRef, CPSV["referenceDoc"], referenceDoc))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))

        if self.identifier:
            g.add((self.uriRef, L0["identifier"], self.identifier))



from .AccrualPeriodicity import AccrualPeriodicity
from .CalculationMethod import CalculationMethod
from .Correction import Correction
from .DatumSource import DatumSource
from .Indicator import Indicator
from .IndicatorCalculation import IndicatorCalculation
from .IndicatorType import IndicatorType
from .Metric import Metric
from .Parameter import Parameter
from .Purpose import Purpose



from .Accommodation import Accommodation
from .AccommodationChain import AccommodationChain
from .AccommodationRoom import AccommodationRoom
from .AccommodationStarRating import AccommodationStarRating
from .AccommodationTypology import AccommodationTypology
from .Bedroom import Bedroom
from .DoubleRoom import DoubleRoom
from .MeetingRoom import MeetingRoom
from .OfferedServiceDescription import OfferedServiceDescription
from .OSDCriterion import OSDCriterion
from .OSDFeature import OSDFeature
from .QuadrupleRoom import QuadrupleRoom
from .SingleRoom import SingleRoom
from .Suite import Suite
from .TripleRoom import TripleRoom


from __future__ import annotations

from typing import TYPE_CHECKING, List

from rdflib import URIRef

from ..ns import *
from .TemporalEntity import TemporalEntity

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..Thing import Thing


class DayOfWeek(TemporalEntity):
    __type__ = TI["DayOfWeek"]

    isDayOfWeekOf: List[Thing] = []
    day: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        for isDayOfWeekOf in self.isDayOfWeekOf:
            g.add((self.uriRef, TI["isDayOfWeekOf"],
                  isDayOfWeekOf.uriRef))

        if self.day:
            g.add((self.uriRef, TI["day"], self.day))


class Monday(DayOfWeek):
    def __init__(self):
        self.uriRef = URIRef(TI["Monday"])


class Tuesday(DayOfWeek):
    def __init__(self):
        self.uriRef = URIRef(TI["Tuesday"])


class Wednesday(DayOfWeek):
    def __init__(self):
        self.uriRef = URIRef(TI["Wednesday"])


class Thursday(DayOfWeek):
    def __init__(self):
        self.uriRef = URIRef(TI["Thursday"])


class Friday(DayOfWeek):
    def __init__(self):
        self.uriRef = URIRef(TI["Friday"])


class Saturday(DayOfWeek):
    def __init__(self):
        self.uriRef = URIRef(TI["Saturday"])


class Sunday(DayOfWeek):
    def __init__(self):
        self.uriRef = URIRef(TI["Sunday"])



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .AmendmentDocument import AmendmentDocument

if TYPE_CHECKING:
    from rdflib import Graph

    from .ResolutionReason import ResolutionReason


class ResolutionDocument(AmendmentDocument):
    __type__ = PUBC["ResolutionDocument"]

    resolutionReason: List[ResolutionReason] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.resolutionReason:
            for resolutionReason in self.resolutionReason:
                g.add(
                    (self.uriRef, PUBC["resolutionReason"], resolutionReason.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .ProcurementDocument import ProcurementDocument

if TYPE_CHECKING:
    from rdflib import Graph

    from .CommonProcurementVocabulary import CommonProcurementVocabulary
    from .NoticeType import NoticeType


class Notice(ProcurementDocument):
    __type__ = PUBC["Notice"]

    hasCPV: List[CommonProcurementVocabulary] = None
    hasNoticeType: NoticeType = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasCPV:
            for hasCPV in self.hasCPV:
                g.add((self.uriRef, PUBC["hasCPV"], hasCPV.uriRef))

        if self.hasNoticeType:
            g.add((self.uriRef, PUBC["hasNoticeType"],
                  self.hasNoticeType.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from ..Thing import Thing


class Image(Object):
    __type__ = SM["Image"]

    isImageOf: List[Thing] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isImageOf:
            for isImageOf in self.isImageOf:
                g.add((self.uriRef, SM["isImageOf"], isImageOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..l0.Entity import Entity
    from ..ro.TimeIndexedRole import TimeIndexedRole


class Role(Object):
    __type__ = RO["Role"]

    isRoleIn: List[TimeIndexedRole] = None
    isRoleOf: List[Entity] = None
    name: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isRoleIn:
            for isRoleIn in self.isRoleIn:
                g.add((self.uriRef, RO["isRoleIn"], isRoleIn.uriRef))

        if self.isRoleOf:
            for isRoleOf in self.isRoleOf:
                g.add((self.uriRef, RO["isRoleOf"], isRoleOf.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from ..poi.MultiplePointOfInterest import MultiplePointOfInterest
from .Accommodation import Accommodation

if TYPE_CHECKING:
    from rdflib import Graph


class AccommodationChain(Accommodation, MultiplePointOfInterest):
    __type__ = ACCO["AccommodationChain"]

    includesAccommodation: List[Accommodation] = None

    def _addProperties(self, g: Graph):
        MultiplePointOfInterest._addProperties(self, g)
        Accommodation._addProperties(self, g)

        if self.includesAccommodation:
            for includesAccommodation in self.includesAccommodation:
                g.add(
                    (self.uriRef, ACCO["includesAccommodation"], includesAccommodation.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from ..poi.PointOfInterest import PointOfInterest

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..l0.Agent import Agent
    from ..pot.Offer import Offer
    from ..sm.OnlineContactPoint import OnlineContactPoint
    from ..sm.Review import Review
    from .AccommodationChain import AccommodationChain
    from .AccommodationRoom import AccommodationRoom
    from .AccommodationStarRating import AccommodationStarRating
    from .AccommodationTypology import AccommodationTypology
    from .OfferedServiceDescription import OfferedServiceDescription


class Accommodation(PointOfInterest):
    __type__ = ACCO["Accommodation"]

    accommodationCode: List[Literal] = None
    hasAccommodationTypology: List[AccommodationTypology] = None
    hasAccommodationRoom: List[AccommodationRoom] = None
    hasOfferedServiceDescription: List[OfferedServiceDescription] = None
    isIncludedInAccommodation: List[AccommodationChain] = None
    hasOffer: List[Offer] = None
    hasReview: List[Review] = None
    hasAccommodationClassification: AccommodationStarRating = None
    hasAccommodationOwner: Agent = None
    hasOnlineContactPoint: OnlineContactPoint = None
    totalBed: Literal = None
    totalRoom: Literal = None
    totalToilet: Literal = None
    checkIn: Literal = None
    checkOut: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.accommodationCode:
            for accommodationCode in self.accommodationCode:
                g.add(
                    (self.uriRef, ACCO["accommodationCode"], accommodationCode))

        if self.hasAccommodationTypology:
            for hasAccommodationTypology in self.hasAccommodationTypology:
                g.add(
                    (self.uriRef, ACCO["hasAccommodationTypology"], hasAccommodationTypology.uriRef))

        if self.hasAccommodationRoom:
            for hasAccommodationRoom in self.hasAccommodationRoom:
                g.add(
                    (self.uriRef, ACCO["hasAccommodationRoom"], hasAccommodationRoom.uriRef))

        if self.hasOfferedServiceDescription:
            for hasOfferedServiceDescription in self.hasOfferedServiceDescription:
                g.add(
                    (self.uriRef, ACCO["hasOfferedServiceDescription"], hasOfferedServiceDescription.uriRef))

        if self.isIncludedInAccommodation:
            for isIncludedInAccommodation in self.isIncludedInAccommodation:
                g.add(
                    (self.uriRef, ACCO["isIncludedInAccommodation"], isIncludedInAccommodation.uriRef))

        if self.hasOffer:
            for hasOffer in self.hasOffer:
                g.add((self.uriRef, POT["hasOffer"], hasOffer.uriRef))

        if self.hasReview:
            for hasReview in self.hasReview:
                g.add((self.uriRef, SM["hasReview"], hasReview.uriRef))

        if self.hasAccommodationClassification:
            g.add((self.uriRef, ACCO["hasAccommodationClassification"],
                  self.hasAccommodationClassification.uriRef))

        if self.hasAccommodationOwner:
            g.add((self.uriRef, ACCO["hasAccommodationOwner"],
                  self.hasAccommodationOwner.uriRef))

        if self.hasOnlineContactPoint:
            g.add((self.uriRef, SM["hasOnlineContactPoint"],
                  self.hasOnlineContactPoint.uriRef))

        if self.totalBed:
            g.add((self.uriRef, ACCO["totalBed"], self.totalBed))

        if self.totalRoom:
            g.add((self.uriRef, ACCO["totalRoom"], self.totalRoom))

        if self.totalToilet:
            g.add((self.uriRef, ACCO["totalToilet"], self.totalToilet))

        if self.checkIn:
            g.add((self.uriRef, ACCO["checkIn"], self.checkIn))

        if self.checkOut:
            g.add((self.uriRef, ACCO["checkOut"], self.checkOut))



from __future__ import annotations

from ..ns import *
from .AcademicDiscipline import AcademicDiscipline


class ScientificDisciplinarySector(AcademicDiscipline):
    __type__ = HER["ScientificDisciplinarySector"]



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Description import Description
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Indicator import Indicator


class Purpose(Description):
    __type__ = INDIC["Purpose"]

    isMetByIndicator: List[Indicator] = None
    name: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isMetByIndicator:
            for isMetByIndicator in self.isMetByIndicator:
                g.add(
                    (self.uriRef, INDIC["isMetByIndicator"], isMetByIndicator.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Service import Service

if TYPE_CHECKING:
    from rdflib import Graph

    from ..l0.EventOrSituation import EventOrSituation
    from ..language.Language import Language
    from .InteractivityLevel import InteractivityLevel
    from .ServiceSector import ServiceSector
    from .ServiceTheme import ServiceTheme


class PublicService(Service):
    __type__ = CPSV["PublicService"]

    serviceSector: List[ServiceSector] = None
    serviceTheme: List[ServiceTheme] = None
    isPartOfEvent: List[EventOrSituation] = None
    hasLanguage: List[Language] = None
    hasiInteractivityLevel: InteractivityLevel = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.serviceSector:
            for serviceSector in self.serviceSector:
                g.add(
                    (self.uriRef, CPSV["serviceSector"], serviceSector.uriRef))

        if self.serviceTheme:
            for serviceTheme in self.serviceTheme:
                g.add((self.uriRef, CPSV["serviceTheme"], serviceTheme.uriRef))

        if self.isPartOfEvent:
            for isPartOfEvent in self.isPartOfEvent:
                g.add(
                    (self.uriRef, CPSV["isPartOfEvent"], isPartOfEvent.uriRef))

        if self.hasLanguage:
            for hasLanguage in self.hasLanguage:
                g.add((self.uriRef, LANG["hasLanguage"], hasLanguage.uriRef))

        if self.hasiInteractivityLevel:
            g.add((self.uriRef, CPSV["hasiInteractivityLevel"],
                  self.hasiInteractivityLevel.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class CivicNumbering(Characteristic):
    __type__ = CLV["CivicNumbering"]

    streetNumber: Literal = None
    exponent: Literal = None
    metric: Literal = None
    peculiarity: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.streetNumber:
            g.add((self.uriRef, CLV["streetNumber"], self.streetNumber))

        if self.exponent:
            g.add((self.uriRef, CLV["exponent"], self.exponent))

        if self.metric:
            g.add((self.uriRef, CLV["metric"], self.metric))

        if self.peculiarity:
            g.add((self.uriRef, CLV["peculiarity"], self.peculiarity))



from __future__ import annotations

from typing import TYPE_CHECKING

from ..ns import *
from .Person import Person

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..l0.Location import Location


class Dead(Person):
    __type__ = CPV["Dead"]

    hasDeathPlace: Location = None
    ageWhenDead: Literal = None
    dateOfDeath: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasDeathPlace:
            g.add((self.uriRef, CPV["hasDeathPlace"],
                  self.hasDeathPlace.uriRef))

        if self.ageWhenDead:
            g.add((self.uriRef, CPV["ageWhenDead"], self.ageWhenDead))

        if self.dateOfDeath:
            g.add((self.uriRef, CPV["dateOfDeath"], self.dateOfDeath))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .TimeInterval import TimeInterval

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..Thing import Thing


class Duration(TimeInterval):
    __type__ = TI["Duration"]

    isDurationOf: List[Thing] = []
    duration: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        for isDurationOf in self.isDurationOf:
            g.add((self.uriRef, TI["isDurationOf"],
                  isDurationOf.uriRef))

        if self.duration:
            g.add((self.uriRef, TI["duration"], self.duration))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from ..route.Route import Route

if TYPE_CHECKING:
    from rdflib import Graph

    from ..l0.Agent import Agent


class Pathway(Route):
    __type__ = PATHS["Pathway"]

    hasMaintainer: List[Agent] = None
    hasSurveillance: List[Agent] = None
    hasMember: List[Agent] = None
    hasFirstMember: List[Agent] = None
    hasLastMember: List[Agent] = None
    hasQuantityOfPaving: List[Agent] = None
    hasSecurityLevel: List[Agent] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasMaintainer:
            for hasMaintainer in self.hasMaintainer:
                g.add(
                    (self.uriRef, PATHS["hasMaintainer"], hasMaintainer.uriRef))

        if self.hasSurveillance:
            for hasSurveillance in self.hasSurveillance:
                g.add(
                    (self.uriRef, PATHS["hasSurveillance"], hasSurveillance.uriRef))

        if self.hasMember:
            for hasMember in self.hasMember:
                g.add((self.uriRef, PATHS["hasMember"], hasMember.uriRef))

        if self.hasFirstMember:
            for hasFirstMember in self.hasFirstMember:
                g.add(
                    (self.uriRef, PATHS["hasFirstMember"], hasFirstMember.uriRef))

        if self.hasLastMember:
            for hasLastMember in self.hasLastMember:
                g.add(
                    (self.uriRef, PATHS["hasLastMember"], hasLastMember.uriRef))

        if self.hasQuantityOfPaving:
            for hasQuantityOfPaving in self.hasQuantityOfPaving:
                g.add(
                    (self.uriRef, PATHS["hasQuantityOfPaving"], hasQuantityOfPaving.uriRef))

        if self.hasSecurityLevel:
            for hasSecurityLevel in self.hasSecurityLevel:
                g.add(
                    (self.uriRef, PATHS["hasSecurityLevel"], hasSecurityLevel.uriRef))



from __future__ import annotations

from rdflib import URIRef

from ..ns import *
from ..ro.Role import Role


class RoleOnService(Role):
    __type__ = CPSV["RoleOnService"]


class Concessionaire(RoleOnService):
    def __init__(self):
        self.uriRef = URIRef(CPSV["Concessionaire"])


class Creator(RoleOnService):
    def __init__(self):
        self.uriRef = URIRef(CPSV["Creator"])


class Maintainer(RoleOnService):
    def __init__(self):
        self.uriRef = URIRef(CPSV["Maintainer"])


class Provider(RoleOnService):
    def __init__(self):
        self.uriRef = URIRef(CPSV["Provider"])


class RightsHolder(RoleOnService):
    def __init__(self):
        self.uriRef = URIRef(CPSV["RightsHolder"])


class User(RoleOnService):
    def __init__(self):
        self.uriRef = URIRef(CPSV["User"])



from __future__ import annotations

from typing import TYPE_CHECKING, List

from rdflib import URIRef

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class CISType(Characteristic):
    __type__ = CIS["CISType"]

    description: List[Literal] = None
    name: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))


class ArchaeologicalArea(CISType):
    def __init__(self):
        self.uriRef = URIRef(CIS["ArchaeologicalArea"])


class ArchaeologicalPark(CISType):
    def __init__(self):
        self.uriRef = URIRef(CIS["ArchaeologicalPark"])


class Cinema(CISType):
    def __init__(self):
        self.uriRef = URIRef(CIS["Cinema"])


class CulturalLandscapeAsset(CISType):
    def __init__(self):
        self.uriRef = URIRef(CIS["CulturalLandscapeAsset"])


class CultResearchCenter(CISType):
    def __init__(self):
        self.uriRef = URIRef(CIS["CultResearchCenter"])


class HolderOfArchive(CISType):
    def __init__(self):
        self.uriRef = URIRef(CIS["HolderOfArchive"])


class Library(CISType):
    def __init__(self):
        self.uriRef = URIRef(CIS["Library"])


class MonumentalArea(CISType):
    def __init__(self):
        self.uriRef = URIRef(CIS["MonumentalArea"])


class Museum(CISType):
    def __init__(self):
        self.uriRef = URIRef(CIS["Museum"])


class Theatre(CISType):
    def __init__(self):
        self.uriRef = URIRef(CIS["Theatre"])



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .AmendmentDocument import AmendmentDocument

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .VariantReason import VariantReason


class VariantDocument(AmendmentDocument):
    __type__ = PUBC["VariantDocument"]

    variantReason: List[VariantReason] = None
    additionalDay: List[Literal] = None
    increaseAmount: List[Literal] = None
    reductionAmount: List[Literal] = None
    variantDate: List[Literal] = None
    variantType: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.variantReason:
            for variantReason in self.variantReason:
                g.add(
                    (self.uriRef, PUBC["variantReason"], variantReason.uriRef))

        if self.additionalDay:
            for additionalDay in self.additionalDay:
                g.add((self.uriRef, PUBC["additionalDay"], additionalDay))

        if self.increaseAmount:
            for increaseAmount in self.increaseAmount:
                g.add((self.uriRef, PUBC["increaseAmount"], increaseAmount))

        if self.reductionAmount:
            for reductionAmount in self.reductionAmount:
                g.add((self.uriRef, PUBC["reductionAmount"], reductionAmount))

        if self.variantDate:
            for variantDate in self.variantDate:
                g.add((self.uriRef, PUBC["variantDate"], variantDate))

        if self.variantType:
            for variantType in self.variantType:
                g.add((self.uriRef, PUBC["variantType"], variantType))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Document import Document

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .WorkProgressReport import WorkProgressReport


class PaymentCertificate(Document):
    __type__ = PUBC["PaymentCertificate"]

    approvedInWPR: List[WorkProgressReport] = None
    paymentAmount: List[Literal] = None
    paymentCetificateDate: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.approvedInWPR:
            for approvedInWPR in self.approvedInWPR:
                g.add(
                    (self.uriRef, PUBC["approvedInWPR"], approvedInWPR.uriRef))

        if self.paymentAmount:
            for paymentAmount in self.paymentAmount:
                g.add((self.uriRef, PUBC["paymentAmount"], paymentAmount))

        if self.paymentCetificateDate:
            for paymentCetificateDate in self.paymentCetificateDate:
                g.add(
                    (self.uriRef, PUBC["paymentCetificateDate"], paymentCetificateDate))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Document import Document

if TYPE_CHECKING:
    from rdflib import Graph

    from .PaymentCertificate import PaymentCertificate


class VariantDocument(Document):
    __type__ = PUBC["VariantDocument"]

    containsPaymentCertificate: List[PaymentCertificate] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.containsPaymentCertificate:
            for containsPaymentCertificate in self.containsPaymentCertificate:
                g.add(
                    (self.uriRef, PUBC["containsPaymentCertificate"], containsPaymentCertificate.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from ..Thing import Thing


class MeasurementUnit(Characteristic):
    __type__ = MU["MeasurementUnit"]

    isMeasurementUnitOf: List[Thing] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isMeasurementUnitOf:
            for isMeasurementUnitOf in self.isMeasurementUnitOf:
                g.add((self.uriRef, MU["isMeasurementUnitOf"],
                       isMeasurementUnitOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from ..Thing import Thing


class Signposting(Characteristic):
    __type__ = PATHS["Signposting"]

    isSignpostingOf: List[Thing] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isSignpostingOf:
            for isSignpostingOf in self.isSignpostingOf:
                g.add(
                    (self.uriRef, PATHS["isSignpostingOf"], isSignpostingOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from ..clv.Country import Country
    from ..Thing import Thing


class Language(Characteristic):
    __type__ = LANG["Language"]

    isLanguageOf: List[Thing] = None
    spokenIn: List[Country] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isLanguageOf:
            for isLanguageOf in self.isLanguageOf:
                g.add((self.uriRef, LANG["isLanguageOf"], isLanguageOf.uriRef))

        if self.spokenIn:
            for spokenIn in self.spokenIn:
                g.add((self.uriRef, LANG["spokenIn"], spokenIn.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class Document(Object):
    __type__ = PUBC["Document"]

    identifier: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.identifier:
            g.add((self.uriRef, L0["identifier"], self.identifier))



from __future__ import annotations

from typing import TYPE_CHECKING

from ..ns import *
from .SupportUnit import SupportUnit

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .eInvoiceService import eInvoiceService
    from .HomogeneousOrganizationalArea import HomogeneousOrganizationalArea


class Office(SupportUnit):
    __type__ = COV["Office"]

    hasEInvoiceService: eInvoiceService = None
    isPartOf: HomogeneousOrganizationalArea = None
    officeIdentifier: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasEInvoiceService:
            for hasEInvoiceService in self.hasEInvoiceService:
                g.add(
                    (self.uriRef, COV["hasEInvoiceService"], hasEInvoiceService.uriRef))

        if self.isPartOf:
            for isPartOf in self.isPartOf:
                g.add((self.uriRef, COV["isPartOf"], isPartOf.uriRef))

        if self.officeIdentifier:
            g.add((self.uriRef, COV["officeIdentifier"],
                  self.officeIdentifier))



from __future__ import annotations

from ..ns import *
from .PublicInvestmentProject import PublicInvestmentProject


class ProcurementProject(PublicInvestmentProject):
    __type__ = PROJ["ProcurementProject"]



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .TemporalEntity import TemporalEntity

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..Thing import Thing


class Year(TemporalEntity):
    __type__ = TI["Year"]

    year: Literal = None
    isYearOf: List[Thing] = []

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        for isYearOf in self.isYearOf:
            g.add((self.uriRef, TI["isYearOf"], isYearOf.uriRef))

        if self.year:
            g.add((self.uriRef, TI["year"], self.year))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Description import Description
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .RegisteredFamily import RegisteredFamily


class ParentalRelationshipType(Description):
    __type__ = CPV["ParentalRelationshipType"]

    inRegisteredFamily: List[RegisteredFamily] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.inRegisteredFamily:
            for inRegisteredFamily in self.inRegisteredFamily:
                g.add(
                    (self.uriRef, CPV["inRegisteredFamily"], inRegisteredFamily.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Object import Object
from ..ns import *
from ..poi.MultiplePointOfInterest import MultiplePointOfInterest

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class Stage(MultiplePointOfInterest, Object):
    __type__ = ROUTE["Stage"]

    directlyFollows: List[Stage] = None
    directlyPrecedes: List[Stage] = None
    follows: List[Stage] = None
    precedes: List[Stage] = None
    stageOrdering: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.directlyFollows:
            for directlyFollows in self.directlyFollows:
                g.add(
                    (self.uriRef, L0["directlyFollows"], directlyFollows.uriRef))

        if self.directlyPrecedes:
            for directlyPrecedes in self.directlyPrecedes:
                g.add(
                    (self.uriRef, L0["directlyPrecedes"], directlyPrecedes.uriRef))

        if self.follows:
            for follows in self.follows:
                g.add((self.uriRef, L0["follows"], follows.uriRef))

        if self.precedes:
            for precedes in self.precedes:
                g.add((self.uriRef, L0["precedes"], precedes.uriRef))

        if self.stageOrdering:
            g.add((self.uriRef, ROUTE["stageOrdering"], self.stageOrdering))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Accommodation import Accommodation


class AccommodationStarRating(Characteristic):
    __type__ = ACCO["AccommodationStarRating"]

    isAccommodationClassificationOf: List[Accommodation] = None
    accoStarRatingLabel: List[Literal] = None
    accoStarRatingID: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isAccommodationClassificationOf:
            for isAccommodationClassificationOf in self.isAccommodationClassificationOf:
                g.add((self.uriRef, ACCO["isAccommodationClassificationOf"],
                      isAccommodationClassificationOf.uriRef))

        if self.accoStarRatingLabel:
            for accoStarRatingLabel in self.accoStarRatingLabel:
                g.add(
                    (self.uriRef, ACCO["accoStarRatingLabel"], accoStarRatingLabel))

        if self.accoStarRatingID:
            for accoStarRatingID in self.accoStarRatingID:
                g.add(
                    (self.uriRef, ACCO["accoStarRatingID"], accoStarRatingID))



from __future__ import annotations

from typing import TYPE_CHECKING

from ..ns import *
from .Family import Family

if TYPE_CHECKING:
    from rdflib import Graph, Literal


class RegisteredFamily(Family):
    __type__ = CPV["RegisteredFamily"]

    registeredFamilyID: Literal = None
    numberRegFamilyComponents: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.registeredFamilyID:
            g.add(
                (self.uriRef, CPV["registeredFamilyID"], self.registeredFamilyID))

        if self.numberRegFamilyComponents:
            g.add(
                (self.uriRef, CPV["numberRegFamilyComponents"], self.numberRegFamilyComponents))



from __future__ import annotations

from rdflib import URIRef

from ..l0.Characteristic import Characteristic
from ..ns import *


class EventType(Characteristic):
    __type__ = CPSV["EventType"]


class Closing(EventType):
    def __init__(self):
        self.uriRef = URIRef(CPSV["Closing"])


class Doing(EventType):
    def __init__(self):
        self.uriRef = URIRef(CPSV["Doing"])


class Starting(EventType):
    def __init__(self):
        self.uriRef = URIRef(CPSV["Starting"])


class StartingCrossBorder(EventType):
    def __init__(self):
        self.uriRef = URIRef(CPSV["StartingCrossBorder"])



from rdflib import URIRef

from ..l0.Characteristic import Characteristic
from ..ns import *


class EventFormat(Characteristic):
    __type__ = CPEV["EventFormat"]


class Physical(EventFormat):
    def __init__(self):
        self.uriRef = URIRef(CPEV["Physical"])


class Virtual(EventFormat):
    def __init__(self):
        self.uriRef = URIRef(CPEV["Virtual"])



from __future__ import annotations

from typing import TYPE_CHECKING, List, Union

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..l0.Activity import Activity
    from .Format import Format
    from .TransparencyActivity import TransparencyActivity
    from .UpdateFrequency import UpdateFrequency


class TransparencyResource(Object):
    __type__ = TRANSP["TransparencyResource"]

    refersToTransparencyEntity: List[Union[Activity, Object]] = None
    generatedBy: List[TransparencyActivity] = None
    hasAllowedFormat: List[Format] = None
    mustBeUptodatedWithin: List[UpdateFrequency] = None
    generatedBy: List[TransparencyActivity] = None
    isVersionOf: List[TransparencyResource] = None
    name: List[Literal] = None
    downloadURL: List[Literal] = None
    accessURL: Literal = None
    modified: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.refersToTransparencyEntity:
            for refersToTransparencyEntity in self.refersToTransparencyEntity:
                g.add(
                    (self.uriRef, TRANSP["refersToTransparencyEntity"], refersToTransparencyEntity.uriRef))

        if self.generatedBy:
            for generatedBy in self.generatedBy:
                g.add((self.uriRef, TRANSP["generatedBy"], generatedBy.uriRef))

        if self.hasAllowedFormat:
            for hasAllowedFormat in self.hasAllowedFormat:
                g.add(
                    (self.uriRef, TRANSP["hasAllowedFormat"], hasAllowedFormat.uriRef))

        if self.mustBeUptodatedWithin:
            for mustBeUptodatedWithin in self.mustBeUptodatedWithin:
                g.add(
                    (self.uriRef, TRANSP["mustBeUptodatedWithin"], mustBeUptodatedWithin.uriRef))

        if self.generatedBy:
            for generatedBy in self.generatedBy:
                g.add((self.uriRef, TRANSP["generatedBy"], generatedBy.uriRef))

        if self.isVersionOf:
            for isVersionOf in self.isVersionOf:
                g.add((self.uriRef, TRANSP["isVersionOf"], isVersionOf.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, TRANSP["name"], name))

        if self.downloadURL:
            for downloadURL in self.downloadURL:
                g.add((self.uriRef, TRANSP["downloadURL"], downloadURL))

        if self.accessURL:
            g.add((self.uriRef, TRANSP["accessURL"], self.accessURL))

        if self.modified:
            g.add((self.uriRef, TRANSP["modified"], self.modified))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Entity import Entity
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..iot.Observation import Observation
    from .IndicatorCalculation import IndicatorCalculation


class Address(Entity):
    __type__ = INDIC["Address"]

    isDatumSourceOf: List[IndicatorCalculation] = None
    isProvidedBy: List[Observation] = None
    name: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isDatumSourceOf:
            for isDatumSourceOf in self.isDatumSourceOf:
                g.add(
                    (self.uriRef, INDIC["isDatumSourceOf"], isDatumSourceOf.uriRef))

        if self.isProvidedBy:
            for isProvidedBy in self.isProvidedBy:
                g.add(
                    (self.uriRef, INDIC["isProvidedBy"], isProvidedBy.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Indicator import Indicator


class IndicatorType(Characteristic):
    __type__ = INDIC["IndicatorType"]

    isIndicatorTypeOf: List[Indicator] = None
    name: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isIndicatorTypeOf:
            for isIndicatorTypeOf in self.isIndicatorTypeOf:
                g.add(
                    (self.uriRef, INDIC["isIndicatorTypeOf"], isIndicatorTypeOf.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, l0["name"], name))



from ..l0.EventOrSituation import EventOrSituation
from ..ns import *
from ..ti.TimeIndexedEvent import TimeIndexedEvent


class Event(TimeIndexedEvent, EventOrSituation):
    __type__ = CPEV["Event"]



from .Call import Call
from .ProcurementProject import ProcurementProject
from .Programme import Programme
from .PublicInvestmentProject import PublicInvestmentProject
from .PublicResearchProject import PublicResearchProject
from .Summary import Summary
from .UniqueProjectCode import UniqueProjectCode
from .WorkPackage import WorkPackage


from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .IndicatorCalculation import IndicatorCalculation
    from .Parameter import Parameter


class Metric(Characteristic):
    __type__ = INDIC["Metric"]

    isMetricOf: List[IndicatorCalculation] = None
    hasParameter: List[Parameter] = None
    description: List[Literal] = None
    description: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isMetricOf:
            for isMetricOf in self.isMetricOf:
                g.add(
                    (self.uriRef, INDIC["isMetricOf"], isMetricOf.uriRef))

        if self.hasParameter:
            for hasParameter in self.hasParameter:
                g.add(
                    (self.uriRef, INDIC["hasParameter"], hasParameter.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from ..accesscondition.AccessCondition import AccessCondition
    from .ChannelType import ChannelType
    from .Cost import Cost
    from .Service import Service


class Channel(Object):
    __type__ = CPSV["Channel"]

    hasCost: List[Cost] = None
    isChannelOf: List[Service] = None
    hasChannelType: ChannelType = None
    hasAccessCondition: AccessCondition = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasCost:
            for hasCost in self.hasCost:
                g.add((self.uriRef, CPSV["hasCost"], hasCost.uriRef))

        if self.isChannelOf:
            for isChannelOf in self.isChannelOf:
                g.add((self.uriRef, CPSV["isChannelOf"], isChannelOf.uriRef))

        if self.hasChannelType:
            g.add((self.uriRef, CPSV["hasChannelType"],
                  self.hasChannelType.uriRef))

        if self.hasAccessCondition:
            g.add(
                (self.uriRef, ACOND["hasAccessCondition"], self.hasAccessCondition.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from ..Thing import Thing

if TYPE_CHECKING:
    from rdflib import Graph

    from .Collection import Collection
    from .Description import Description
    from .Sequence import Sequence
    from .Topic import Topic


class Entity(Thing):
    __type__ = L0["Entity"]

    directlyFollows: List[Entity] = None
    directlyPrecedes: List[Entity] = None
    follows: List[Entity] = None
    hasDescription: List[Description] = None
    hasLastMember: List[Sequence] = None
    hasTopic: List[Topic] = None
    isFirstMemberOf: List[Sequence] = None
    isLastMemberOf: List[Sequence] = None
    isMemberOf: List[Collection] = None
    precedes: List[Entity] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.directlyFollows:
            for directlyFollows in self.directlyFollows:
                g.add(
                    (self.uriRef, L0["directlyFollows"], directlyFollows.uriRef))

        if self.directlyPrecedes:
            for directlyPrecedes in self.directlyPrecedes:
                g.add((self.uriRef, L0["directlyPrecedes"],
                       directlyPrecedes.uriRef))

        if self.follows:
            for follows in self.follows:
                g.add((self.uriRef, L0["follows"], follows.uriRef))

        if self.hasDescription:
            for hasDescription in self.hasDescription:
                g.add((self.uriRef, L0["hasDescription"],
                      hasDescription.uriRef))

        if self.hasLastMember:
            for hasLastMember in self.hasLastMember:
                g.add((self.uriRef, L0["hasLastMember"], hasLastMember.uriRef))

        if self.hasTopic:
            for hasTopic in self.hasTopic:
                g.add((self.uriRef, L0["hasTopic"], hasTopic.uriRef))

        if self.isFirstMemberOf:
            for isFirstMemberOf in self.isFirstMemberOf:
                g.add(
                    (self.uriRef, L0["isFirstMemberOf"], isFirstMemberOf.uriRef))

        if self.isLastMemberOf:
            for isLastMemberOf in self.isLastMemberOf:
                g.add((self.uriRef, L0["isLastMemberOf"],
                      isLastMemberOf.uriRef))

        if self.isMemberOf:
            for isMemberOf in self.isMemberOf:
                g.add((self.uriRef, L0["isMemberOf"], isMemberOf.uriRef))

        if self.precedes:
            for precedes in self.precedes:
                g.add((self.uriRef, L0["precedes"], precedes.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .SpatialObject import SpatialObject

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..Thing import Thing
    from .GeometryType import GeometryType


class Geometry(SpatialObject):
    __type__ = CLV["Geometry"]

    hasGeometryType: GeometryType = None
    lat: Literal = None
    long: Literal = None
    alt: Literal = None
    coordinate: Literal = None
    coordinateSystem: Literal = None
    serialization: Literal = None
    isGeometryFor: List[Thing] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasGeometryType:
            g.add((self.uriRef, CLV["hasGeometryType"],
                  self.hasGeometryType.uriRef))

        if self.lat:
            g.add((self.uriRef, CLV["lat"], self.lat))

        if self.long:
            g.add((self.uriRef, CLV["long"], self.long))

        if self.alt:
            g.add((self.uriRef, CLV["alt"], self.alt))

        if self.coordinate:
            g.add((self.uriRef, CLV["coordinate"], self.coordinate))

        if self.coordinateSystem:
            g.add((self.uriRef, CLV["coordinateSystem"],
                  self.coordinateSystem))

        if self.serialization:
            g.add((self.uriRef, CLV["serialization"], self.serialization))

        if self.isGeometryFor:
            for isGeometryFor in self.isGeometryFor:
                g.add(
                    (self.uriRef, CLV["isGeometryFor"], isGeometryFor.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Characteristic import Characteristic
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .ProcedureChangeEvent import ProcedureChangeEvent


class EconomicSummary(Characteristic):
    __type__ = PUBC["EconomicSummary"]

    changedByProcedureChangeEvent: List[ProcedureChangeEvent] = None
    resultedFrom: List[ProcedureChangeEvent] = None
    availableAmount: List[Literal] = None
    estimatedEndDate: List[Literal] = None
    planningAmount: List[Literal] = None
    safetyAmount: List[Literal] = None
    servicesAmount: List[Literal] = None
    nonDiscountableSum: List[Literal] = None
    suppliesAmount: List[Literal] = None
    totalAmount: List[Literal] = None
    worksAmount: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.changedByProcedureChangeEvent:
            for changedByProcedureChangeEvent in self.changedByProcedureChangeEvent:
                g.add((self.uriRef, PUBC["changedByProcedureChangeEvent"],
                      changedByProcedureChangeEvent.uriRef))

        if self.resultedFrom:
            for resultedFrom in self.resultedFrom:
                g.add((self.uriRef, PUBC["resultedFrom"], resultedFrom.uriRef))

        if self.availableAmount:
            for availableAmount in self.availableAmount:
                g.add((self.uriRef, PUBC["availableAmount"], availableAmount))

        if self.estimatedEndDate:
            for estimatedEndDate in self.estimatedEndDate:
                g.add(
                    (self.uriRef, PUBC["estimatedEndDate"], estimatedEndDate))

        if self.planningAmount:
            for planningAmount in self.planningAmount:
                g.add((self.uriRef, PUBC["planningAmount"], planningAmount))

        if self.safetyAmount:
            for safetyAmount in self.safetyAmount:
                g.add((self.uriRef, PUBC["safetyAmount"], safetyAmount))

        if self.servicesAmount:
            for servicesAmount in self.servicesAmount:
                g.add((self.uriRef, PUBC["servicesAmount"], servicesAmount))

        if self.nonDiscountableSum:
            for nonDiscountableSum in self.nonDiscountableSum:
                g.add(
                    (self.uriRef, PUBC["nonDiscountableSum"], nonDiscountableSum))

        if self.suppliesAmount:
            for suppliesAmount in self.suppliesAmount:
                g.add((self.uriRef, PUBC["suppliesAmount"], suppliesAmount))

        if self.totalAmount:
            for totalAmount in self.totalAmount:
                g.add((self.uriRef, PUBC["totalAmount"], totalAmount))

        if self.worksAmount:
            for worksAmount in self.worksAmount:
                g.add((self.uriRef, PUBC["worksAmount"], worksAmount))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.EventOrSituation import EventOrSituation
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..ti.TimeInterval import TimeInterval
    from .PointOfInterest import PointOfInterest


class POINameInTime(EventOrSituation):
    __type__ = POI["POINameInTime"]

    isPOINameInTimeFor: PointOfInterest = None
    atTime: TimeInterval = None
    POIofficialName: List[Literal] = None
    POIalternativeName: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isPOINameInTimeFor:
            g.add((self.uriRef, POI["isPOINameInTimeFor"],
                  self.isPOINameInTimeFor.uriRef))

        if self.atTime:
            g.add((self.uriRef, TI["atTime"], self.atTime.uriRef))

        if self.POIofficialName:
            for POIofficialName in self.POIofficialName:
                g.add((self.uriRef, POI["POIofficialName"], POIofficialName))

        if self.POIalternativeName:
            for POIalternativeName in self.POIalternativeName:
                g.add(
                    (self.uriRef, POI["POIalternativeName"], POIalternativeName))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .PublicInvestmentProject import PublicInvestmentProject

if TYPE_CHECKING:
    from rdflib import Graph

    from .WorkPackage import WorkPackage


class PublicResearchProject(PublicInvestmentProject):
    __type__ = PROJ["PublicResearchProject"]

    hasWorkPackage: List[WorkPackage] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasWorkPackage:
            for hasWorkPackage in self.hasWorkPackage:
                g.add(
                    (self.uriRef, PROJ["hasWorkPackage"], hasWorkPackage.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from .Feature import Feature

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .AddressArea import AddressArea
    from .AddressComponent import AddressComponent
    from .AddressInTime import AddressInTime
    from .CensusSection import CensusSection
    from .City import City
    from .CivicNumbering import CivicNumbering
    from .Country import Country
    from .District import District
    from .InternalAccess import InternalAccess
    from .Province import Province
    from .Region import Region
    from .StreetToponym import StreetToponym


class Address(Feature):
    __type__ = CLV["Address"]

    hasAddressComponent: List[AddressComponent] = None
    hasInternalAccess: List[InternalAccess] = None
    hasNumber: CivicNumbering = None
    hasStreetToponym: StreetToponym = None
    hasAdressinTime: AddressInTime = None
    hasCensusSection: CensusSection = None
    fullAddress: Literal = None
    postCode: Literal = None
    hasAddressArea: List[AddressArea] = None
    hasCity: List[City] = None
    hasCountry: List[Country] = None
    hasDistrict: List[District] = None
    hasProvince: List[Province] = None
    hasRegion: List[Region] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasAddressComponent:
            for hasAddressComponent in self.hasAddressComponent:
                g.add(
                    (self.uriRef, CLV["hasAddressComponent"], hasAddressComponent.uriRef))

        if self.hasInternalAccess:
            for hasInternalAccess in self.hasInternalAccess:
                g.add(
                    (self.uriRef, CLV["hasInternalAccess"], hasInternalAccess.uriRef))

        if self.hasNumber:
            g.add((self.uriRef, CLV["hasNumber"], self.hasNumber.uriRef))

        if self.hasStreetToponym:
            g.add((self.uriRef, CLV["hasStreetToponym"],
                  self.hasStreetToponym.uriRef))

        if self.hasAdressinTime:
            g.add((self.uriRef, CLV["hasAdressinTime"],
                  self.hasAdressinTime.uriRef))

        if self.hasCensusSection:
            g.add((self.uriRef, CLV["hasCensusSection"],
                  self.hasCensusSection.uriRef))

        if self.fullAddress:
            g.add((self.uriRef, CLV["fullAddress"], self.fullAddress))

        if self.postCode:
            g.add((self.uriRef, CLV["postCode"], self.postCode))

        if self.hasAddressArea:
            for hasAddressArea in self.hasAddressArea:
                g.add(
                    (self.uriRef, CLV["hasAddressArea"], hasAddressArea.uriRef))

        if self.hasCity:
            for hasCity in self.hasCity:
                g.add(
                    (self.uriRef, CLV["hasCity"], hasCity.uriRef))

        if self.hasCountry:
            for hasCountry in self.hasCountry:
                g.add(
                    (self.uriRef, CLV["hasCountry"], hasCountry.uriRef))

        if self.hasDistrict:
            for hasDistrict in self.hasDistrict:
                g.add(
                    (self.uriRef, CLV["hasDistrict"], hasDistrict.uriRef))

        if self.hasProvince:
            for hasProvince in self.hasProvince:
                g.add(
                    (self.uriRef, CLV["hasProvince"], hasProvince.uriRef))

        if self.hasRegion:
            for hasRegion in self.hasRegion:
                g.add(
                    (self.uriRef, CLV["hasRegion"], hasRegion.uriRef))


from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Entity import Entity
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from ..l0.Characteristic import Characteristic
    from ..Thing import Thing


class TemporalEntity(Entity):
    __type__ = TI["TemporalEntity"]

    hasTimeParameter: List[Characteristic] = []
    isTemporalEntityOf: List[Thing] = []

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        for hasTimeParameter in self.hasTimeParameter:
            g.add((self.uriRef, TI["hasTimeParameter"],
                  hasTimeParameter.uriRef))

        for isTemporalEntityOf in self.isTemporalEntityOf:
            g.add((self.uriRef, TI["isTemporalEntityOf"],
                  isTemporalEntityOf.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Activity import Activity
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .IndicatorCalculation import IndicatorCalculation


class CalculationMethod(Activity):
    __type__ = INDIC["CalculationMethod"]

    isCalculationMethodOf: List[IndicatorCalculation] = None
    name: List[Literal] = None
    description: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isCalculationMethodOf:
            for isCalculationMethodOf in self.isCalculationMethodOf:
                g.add(
                    (self.uriRef, INDIC["isCalculationMethodOf"], isCalculationMethodOf.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..ns import *
from ..l0.Entity import Entity

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from .Observation import Observation


class FeatureOfInterest(Entity):
    __type__ = IOT["FeatureOfInterest"]

    isFeatureOfInterestFor: List[Observation] = None
    name: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isFeatureOfInterestFor:
            for isFeatureOfInterestFor in self.isFeatureOfInterestFor:
                g.add(
                    (self.uriRef, IOT["isFeatureOfInterestFor"], isFeatureOfInterestFor.uriRef))

        if self.name:
            for name in self.name:
                g.add((self.uriRef, L0["name"], name))



from __future__ import annotations

from ..ns import *
from .TransparencyActivity import TransparencyActivity


class TransparencyUpdateActivity(TransparencyActivity):
    __type__ = TRANSP["TransparencyUpdateActivity"]



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Object import Object
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph

    from .MonitoringFacility import MonitoringFacility


class Platform(Object):
    __type__ = IOT["Platform"]

    hostsMonitoringFacility: List[MonitoringFacility] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hostsMonitoringFacility:
            for hostsMonitoringFacility in self.hostsMonitoringFacility:
                g.add(
                    (self.uriRef, IOT["hostsMonitoringFacility"], hostsMonitoringFacility.uriRef))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.EventOrSituation import EventOrSituation
from ..ns import *
from ..poi.POINameInTime import POINameInTime

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..ti.TimeInterval import TimeInterval


class CISNameInTime(POINameInTime, EventOrSituation):
    __type__ = CIS["CISNameInTime"]

    isValidDuring: List[TimeInterval] = None
    institutionalCISName: List[Literal] = None
    altCISName: List[Literal] = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.isValidDuring:
            for isValidDuring in self.isValidDuring:
                g.add(
                    (self.uriRef, CIS["isValidDuring"], isValidDuring.uriRef))

        if self.institutionalCISName:
            for institutionalCISName in self.institutionalCISName:
                g.add(
                    (self.uriRef, CIS["institutionalCISName"], institutionalCISName))

        if self.altCISName:
            for altCISName in self.altCISName:
                g.add((self.uriRef, CIS["altCISName"], altCISName))



from __future__ import annotations

from typing import TYPE_CHECKING, List

from ..l0.Activity import Activity
from ..ns import *

if TYPE_CHECKING:
    from rdflib import Graph, Literal

    from ..clv.Geometry import Geometry
    from ..ti.TimeInterval import TimeInterval
    from .FeatureOfInterest import FeatureOfInterest
    from .MeasurementQuality import MeasurementQuality
    from .Method import Method
    from .ObservationCollection import ObservationCollection
    from .ObservationParameter import ObservationParameter
    from .ObservationValue import ObservationValue
    from .Platform import Platform
    from .Sensor import Sensor


class Observation(Activity):
    __type__ = IOT["Observation"]

    hasObservationParameter: List[ObservationParameter] = None
    hasObservationValue: List[ObservationValue] = None
    hasQuality: List[MeasurementQuality] = None
    usedMethod: List[Method] = None
    comesFrom: List[Platform] = None
    hasFeatureOfInterest: FeatureOfInterest = None
    isPartOf: ObservationCollection = None
    observationMadeBySensor: Sensor = None
    hasGeometry: Geometry = None
    generationTime: TimeInterval = None
    phenomenonTime: TimeInterval = None
    atTime: TimeInterval = None
    description: List[Literal] = None
    identifier: Literal = None
    issued: Literal = None
    modified: Literal = None

    def _addProperties(self, g: Graph):
        super()._addProperties(g)

        if self.hasObservationParameter:
            for hasObservationParameter in self.hasObservationParameter:
                g.add(
                    (self.uriRef, IOT["hasObservationParameter"], hasObservationParameter.uriRef))

        if self.hasObservationValue:
            for hasObservationValue in self.hasObservationValue:
                g.add(
                    (self.uriRef, IOT["hasObservationValue"], hasObservationValue.uriRef))

        if self.hasQuality:
            for hasQuality in self.hasQuality:
                g.add((self.uriRef, IOT["hasQuality"], hasQuality.uriRef))

        if self.usedMethod:
            for usedMethod in self.usedMethod:
                g.add((self.uriRef, IOT["usedMethod"], usedMethod.uriRef))

        if self.comesFrom:
            for comesFrom in self.comesFrom:
                g.add((self.uriRef, IOT["comesFrom"], comesFrom.uriRef))

        if self.hasFeatureOfInterest:
            g.add((self.uriRef, IOT["hasFeatureOfInterest"],
                  self.hasFeatureOfInterest.uriRef))

        if self.isPartOf:
            g.add((self.uriRef, IOT["isPartOf"], self.isPartOf.uriRef))

        if self.observationMadeBySensor:
            g.add((self.uriRef, IOT["observationMadeBySensor"],
                  self.observationMadeBySensor.uriRef))

        if self.hasGeometry:
            g.add((self.uriRef, CLV["hasGeometry"], self.hasGeometry.uriRef))

        if self.generationTime:
            g.add((self.uriRef, IOT["generationTime"],
                  self.generationTime.uriRef))

        if self.phenomenonTime:
            g.add((self.uriRef, IOT["phenomenonTime"],
                  self.phenomenonTime.uriRef))

        if self.atTime:
            g.add((self.uriRef, TI["atTime"], self.atTime.uriRef))

        if self.description:
            for description in self.description:
                g.add((self.uriRef, L0["description"], description))

        if self.identifier:
            g.add((self.uriRef, L0["identifier"], self.identifier))

        if self.issued:
            g.add((self.uriRef, TI["issued"], self.issued))

        if self.modified:
            g.add((self.uriRef, TI["modified"], self.modified))



from .Path import Path
from .PathPlan import PathPlan
from .PathStage import PathStage
from .PathTheme import PathTheme
from .Pathway import Pathway
from .Paving import Paving
from .QuantifiedPathwayPaving import QuantifiedPathwayPaving
from .Restaurant import Restaurant
from .SecurityLevel import SecurityLevel
from .Signposting import Signposting
from .SupportService import SupportService
from .ServiceType import ServiceType
from .TravellingMethod import TravellingMethod